/*
 * Copyright 2012 Leviathan.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package mx.com.leviathan.console.command;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

/**
 *
 * @author Leviathan
 */
public abstract class CommandPrototype {

    private List<CommandRule> rules = new ArrayList<CommandRule>();

    public void addRule(CommandRule rule) {
        rules.add(rule);
    }

    public final boolean isEqual(Map<String, Object> values) {
        boolean status = true;
        for (CommandRule rule : rules) {
            if (status) {
                boolean valid = false;
                Iterator<Entry<String, Object>> iterator = values.entrySet().iterator();
                while (iterator.hasNext()) {
                    Entry<String, Object> entry = iterator.next();
                    if (rule.isValid(entry.getKey(), entry.getValue())) {
                        valid = true;
                    }
                }
                status = valid;
            }
        }
        return status;
    }

    public List<CommandRule> getRules() {
        return rules;
    }

    public void setRules(List<CommandRule> rules) {
        this.rules = rules;
    }

    public abstract boolean process(Map<String, Object> values);
}
