/*
 * Copyright 2012 Leviathan.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package mx.com.leviathan.console.event;

import java.util.List;
import java.util.regex.Matcher;
import mx.com.leviathan.console.command.CommandPackage;
import mx.com.leviathan.console.command.Executable;
import mx.com.leviathan.console.io.CommandLine;
import mx.com.leviathan.console.loader.CommandLoader;
import mx.com.leviathan.console.settings.Settings;
import mx.com.leviathan.console.util.RegexUtils;

/**
 *
 * @author Leviathan
 */
public class HelpCommandListener implements CommandLineListener {

    @Override
    public boolean onInput(String line, CommandLine commandLine) {
        if (RegexUtils.match("([\\w]+)[\\s]+--help", line)) {
            Matcher matcher = RegexUtils.matcher("([\\w]+)[\\s]+--help", line);
            matcher.find();
            String name = matcher.group(1);
            Executable executable = CommandLoader.getInstance().loadCommand(name);
            if (executable != null) {
                System.out.println(executable.getName());
                System.out.println("\t-" + executable.getDescription());
                if (executable.getOptions() != null) {
                    System.out.println("\t-Options:");
                    for (String option : executable.getOptions()) {
                        System.out.println("\t\t-" + option);
                    }
                }
            }
            return true;
        } else if (line.equalsIgnoreCase("help")) {
            Settings settings = Settings.getInstance(false);
            List<CommandPackage> packages = settings.getPackages();
            for (CommandPackage commandPackage : packages) {
                for (String[] command : commandPackage.getCommands()) {
                    Executable executable = CommandLoader.getInstance().loadCommand(command[1]);
                    System.out.println(executable.getName());
                    System.out.println("\t-" + executable.getDescription());
                    if (executable.getOptions() != null) {
                        System.out.println("\t-Options:");
                        for (String option : executable.getOptions()) {
                            System.out.println("\t\t-" + option);
                        }
                    }
                }
            }
            return true;
        }
        return false;
    }
}
