/*
 * Copyright 2012 Leviathan.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package mx.com.leviathan.console.io;

import java.io.BufferedReader;
import java.io.Console;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import mx.com.leviathan.console.event.CommandLineListener;

/**
 *
 * @author Leviathan
 */
public class ConsoleCommandLine implements CommandLine {

    private boolean run = true;
    private BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));
    private List<CommandLineListener> commandLineListeners = new ArrayList<CommandLineListener>();

    @Override
    public void start() {
        run = true;
        while (run) {
            System.out.println(">>>\t");
            String line = null;
            try {
                line = reader.readLine();
            } catch (IOException ex) {
                Logger.getLogger(Console.class.getName()).log(Level.SEVERE, null, ex);
            }
            if (line != null) {
                for (CommandLineListener commandLineListener : commandLineListeners) {
                    if (commandLineListener.onInput(line, this)) {
                        break;
                    }
                }
            }
        }
    }

    @Override
    public void stop() {
        run = false;
    }

    @Override
    public boolean isRunning() {
        return run;
    }

    public List<CommandLineListener> getCommandLineListeners() {
        return commandLineListeners;
    }

    public void setCommandLineListeners(List<CommandLineListener> commandLineListeners) {
        this.commandLineListeners = commandLineListeners;
    }
}
