/*
 * Copyright 2012 Leviathan.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package mx.com.leviathan.console.loader;

import java.util.List;
import mx.com.leviathan.console.command.Command;
import mx.com.leviathan.console.command.CommandPackage;
import mx.com.leviathan.console.command.Executable;
import mx.com.leviathan.console.settings.Settings;
import org.xeustechnologies.jcl.JarClassLoader;
import org.xeustechnologies.jcl.JclObjectFactory;
import org.xeustechnologies.jcl.JclUtils;
import org.xeustechnologies.jcl.proxy.CglibProxyProvider;
import org.xeustechnologies.jcl.proxy.ProxyProviderFactory;

/**
 *
 * @author Leviathan
 */
public class CommandLoader {

    private JarClassLoader loader = new JarClassLoader();

    private CommandLoader() {
    }

    public void init() {
        ProxyProviderFactory.setDefaultProxyProvider(new CglibProxyProvider());
        Settings settings = Settings.getInstance(false);
        List<CommandPackage> packages = settings.getPackages();
        for (CommandPackage commandPackage : packages) {
            loader.add(settings.getOptions().get("command_path") + commandPackage.getJar());
        }
    }

    public Command loadCommand(String name) {
        List<CommandPackage> packages = Settings.getInstance(false).getPackages();
        for (CommandPackage commandPackage : packages) {
            for (String[] command : commandPackage.getCommands()) {
                if (command[1].equalsIgnoreCase(name)) {
                    JclObjectFactory factory = JclObjectFactory.getInstance(true);
                    Object object = factory.create(loader, commandPackage.getClassPath() + "." + command[0]);
                    if (object instanceof Executable) {
                        return JclUtils.cast(object, Command.class);
                    }
                }
            }
        }
        return null;
    }

    public static CommandLoader getInstance() {
        return CommandLoaderHolder.INSTANCE;
    }

    private static class CommandLoaderHolder {

        private static final CommandLoader INSTANCE = new CommandLoader();
    }
}
