/*
 * Copyright 2012 Leviathan.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package mx.com.leviathan.console.settings;

import java.io.*;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;
import mx.com.leviathan.console.Console;
import mx.com.leviathan.console.command.CommandPackage;
import org.yaml.snakeyaml.Yaml;

/**
 *
 * @author Leviathan
 */
public class Settings {

    private Map<String, Object> options = new HashMap<String, Object>();
    private List<CommandPackage> packages = new ArrayList<CommandPackage>();

    private Settings() {
    }

    public Map<String, Object> getOptions() {
        return options;
    }

    public void setOptions(Map<String, Object> options) {
        this.options = options;
    }

    public List<CommandPackage> getPackages() {
        return packages;
    }

    public void setPackages(List<CommandPackage> packages) {
        this.packages = packages;
    }

    public void save() {
        FileWriter fileWriter = null;
        try {
            fileWriter = new FileWriter(new File(System.getProperty("user.dir") + "/settings.yml"));
            new Yaml().dump(this, fileWriter);
        } catch (FileNotFoundException ex) {
            Logger.getLogger(Settings.class.getName()).log(Level.SEVERE, null, ex);
        } catch (IOException ex) {
            Logger.getLogger(Settings.class.getName()).log(Level.SEVERE, null, ex);
        } finally {
            try {
                fileWriter.close();
            } catch (IOException ex) {
                Logger.getLogger(Settings.class.getName()).log(Level.SEVERE, null, ex);
            }
        }
    }

    public static Settings getInstance(boolean reload) {
        if (reload) {
            SettingsHolder.INSTANCE = null;
        }
        if (SettingsHolder.INSTANCE == null) {
            FileInputStream fileInputStream = null;
            try {
                fileInputStream = new FileInputStream(new File(System.getProperty("user.dir") + "/settings.yml"));
            } catch (FileNotFoundException ex) {
                Logger.getLogger(Console.class.getName()).log(Level.SEVERE, null, ex);
            }
            if (fileInputStream != null) {
                SettingsHolder.INSTANCE = new Yaml().loadAs(fileInputStream, Settings.class);
                try {
                    fileInputStream.close();
                } catch (IOException ex) {
                    Logger.getLogger(Settings.class.getName()).log(Level.SEVERE, null, ex);
                }
            }
        }
        return SettingsHolder.INSTANCE;
    }

    private static class SettingsHolder {

        private static Settings INSTANCE;
    }
}
